|logo|

|build_status| |documentation_status|
|codecov|
|requirements|


Markdownreveal
==============

A tool for creating presentations with simple Markdown notation. Documentation can be found at the `official website <https://markdownreveal.readthedocs.io/>`_.




.. |logo|
   image:: docs/source/logo/logo.png
      :width: 100px
      :target: https://markdownreveal.readthedocs.io/
.. |build_status|
   image:: https://api.travis-ci.org/Peque/markdownreveal.svg?branch=master
      :target: https://travis-ci.org/Peque/markdownreveal
.. |documentation_status|
   image:: https://readthedocs.org/projects/markdownreveal/badge/
      :target: https://markdownreveal.readthedocs.io/
.. |codecov| image:: https://codecov.io/github/Peque/markdownreveal/coverage.svg?branch=master
   :target: https://codecov.io/github/Peque/markdownreveal
   :alt: Coverage (codecov) badge
.. |requirements| image:: https://requires.io/github/Peque/markdownreveal/requirements.svg
   :target: https://requires.io/github/Peque/markdownreveal/requirements/
   :alt: Requirements badge
